pub struct MockTwoFactorApi {
TwoFactorApi_expectations: MockTwoFactorApi_TwoFactorApi,
}Fields
TwoFactorApi_expectations: MockTwoFactorApi_TwoFactorApiImplementations
Sourceimpl MockTwoFactorApi
impl MockTwoFactorApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockTwoFactorApi
impl MockTwoFactorApi
Sourcepub fn expect_delete_web_authn(&mut self) -> &mut Expectation
pub fn expect_delete_web_authn(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_web_authn method
Sourcepub fn expect_disable_authenticator(&mut self) -> &mut Expectation
pub fn expect_disable_authenticator(&mut self) -> &mut Expectation
Create an Expectation for mocking the disable_authenticator method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_authenticator(&mut self) -> &mut Expectation
pub fn expect_get_authenticator(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_authenticator method
Sourcepub fn expect_get_duo(&mut self) -> &mut Expectation
pub fn expect_get_duo(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_duo method
Sourcepub fn expect_get_email(&mut self) -> &mut Expectation
pub fn expect_get_email(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_email method
Sourcepub fn expect_get_organization(&mut self) -> &mut Expectation
pub fn expect_get_organization(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_organization method
Sourcepub fn expect_get_organization_duo(&mut self) -> &mut Expectation
pub fn expect_get_organization_duo(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_organization_duo method
Sourcepub fn expect_get_recover(&mut self) -> &mut Expectation
pub fn expect_get_recover(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_recover method
Sourcepub fn expect_get_web_authn(&mut self) -> &mut Expectation
pub fn expect_get_web_authn(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_web_authn method
Sourcepub fn expect_get_yubi_key(&mut self) -> &mut Expectation
pub fn expect_get_yubi_key(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_yubi_key method
Sourcepub fn expect_put_authenticator(&mut self) -> &mut Expectation
pub fn expect_put_authenticator(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_authenticator method
Sourcepub fn expect_put_disable(&mut self) -> &mut Expectation
pub fn expect_put_disable(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_disable method
Sourcepub fn expect_put_duo(&mut self) -> &mut Expectation
pub fn expect_put_duo(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_duo method
Sourcepub fn expect_put_email(&mut self) -> &mut Expectation
pub fn expect_put_email(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_email method
Sourcepub fn expect_put_organization_disable(&mut self) -> &mut Expectation
pub fn expect_put_organization_disable(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_organization_disable method
Sourcepub fn expect_put_organization_duo(&mut self) -> &mut Expectation
pub fn expect_put_organization_duo(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_organization_duo method
Sourcepub fn expect_put_web_authn(&mut self) -> &mut Expectation
pub fn expect_put_web_authn(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_web_authn method
Sourcepub fn expect_put_yubi_key(&mut self) -> &mut Expectation
pub fn expect_put_yubi_key(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_yubi_key method
Sourcepub fn expect_send_email(&mut self) -> &mut Expectation
pub fn expect_send_email(&mut self) -> &mut Expectation
Create an Expectation for mocking the send_email method
Sourcepub fn expect_send_email_login(&mut self) -> &mut Expectation
pub fn expect_send_email_login(&mut self) -> &mut Expectation
Create an Expectation for mocking the send_email_login method